import { BasePaginationData, BaseRespData } from '@/types/api'
import axios from './axios'
import {
  LogListData,
  OrderData,
  SearchForm,
  SendOrderData,
  ShipmentForm,
  ShipmentOrderRes,
  Tab,
} from '@/types/api/order'

export function getOrderList(
  data: SearchForm,
  currentPage: number,
  pageSize: number,
) {
  return axios.post<never, BasePaginationData<OrderData>>(
    '/factory/customJomallOrder/list_page',
    { ...data, currentPage, pageSize },
  )
}

export function getOrderTabData() {
  return axios.get<never, BaseRespData<Tab[]>>(
    'factory/customJomallOrder/findStateGroupList',
  )
}
// 确认生产
export function confirmProductionOrder(ids: number[]) {
  return axios.post<never, BaseRespData<never>>(
    'factory/customJomallOrder/confirmProduce',
    ids,
  )
}

// 下载稿件
export function downloadOrder(id: number) {
  return axios.get<never, BaseRespData<never>>(
    'factory/customJomallOrder/downloadMaterial',
    { params: { id } },
  )
}

// 打印生产单
export function printOrder(ids: number[]) {
  return axios.post<never, BaseRespData<never>>(
    'factory/customJomallOrder/printProducePdf',
    ids,
  )
}

// 获取订单详情
export function getOrderBySubOrderNumber(orderNumber: string) {
  return axios.get<never, BaseRespData<OrderData>>(
    'factory/customJomallOrder/getOrderBySubOrderNumber',
    {
      params: {
        subOrderNumber: orderNumber,
      },
    },
  )
}

// 发货保存
export function saveOrder(
  sumbitSendOutList: ShipmentOrderRes[],
  from: ShipmentForm,
) {
  return axios.post<never, BaseRespData<never>>(
    'factory/customJomallOrder/sendOut',
    { sumbitSendOutList, ...from },
  )
}

// 添加内部便签
export function addInternalTagApi(idList: number[], memo: string) {
  return axios.post<never, BaseRespData<never>>(
    'factory/customJomallOrder/batchAddInternalMemo',
    { idList, content: memo },
  )
}
// 查看发货单
export function loadSendOutList(id: number) {
  return axios.get<never, BaseRespData<SendOrderData[]>>(
    'factory/customJomallOrder/getShipmentListByCustomOrderId',
    {
      params: {
        id,
      },
    },
  )
}
// 操作日志
export function getLogList(id: number) {
  return axios.get<never, BaseRespData<LogListData[]>>(
    'factory/customJomallOrder/getLog',
    {
      params: {
        id,
      },
    },
  )
}

// 根据id获取数据详情
export function getOrderDetail(id: number) {
  return axios.get<never, BaseRespData<OrderData>>(
    'factory/customJomallOrder/getOrderById',
    {
      params: {
        id,
      },
    },
  )
}

// 取消
export function cancelOrderApi(id: number) {
  return axios.post<never, BaseRespData<never>>(
    'factory/customJomallOrder/cancel',
    { id },
  )
}
